require 'spec_helper'

describe "DSL" do

  let(:url) { 'http://foo.com' }
  let(:key) { '1234' }
  let(:enterprise_key) { '5678' }
  let(:network) {
    Gamifier.dsl do
      set :label, 'foo'
      set :email, 'foo@bar.com'

      api_key do
        set :access, 'private'
      end

      site 'foo' do
        set :url, 'bar.com'

        unit :karma do
          set :label, 'karma'
          set :abbreviation, 'kar'
        end
      end

    end
  }

  let(:network_response) { '{"id":"5112257849f8387b000e85f6","label":"foo","email":"foo@bar.com","api_explorer_post":null,"permissions":{"api_explorer_posting":true,"social_mechanics":true,"read_only_widgets":true,"show_community_link":true},"attempts":20,"timeout":180,"whitelist_filter":null,"require_strong_passwords":false,"password_reset_in_days":60,"force_password_resets":false,"deny_previous_passwords":false,"enable_ip_whitelist":false}' }
  let(:site_response) { '{"name":"foo","created_at":"2013-02-06T01:44:22-08:00","url":"bar.com","id":"511225f6297c011c62106fb7","_id":"511225f6297c011c62106fb7","network_id":"4fac5d4f3dc6483a0100000b","timed_reset":false,"reset_interval":null,"reset_month":null,"reset_date":null,"reset_day":null,"reset_hour":null,"interval_start":null,"interval_end":null}' }
  let(:unit_response) { '{"id":"511226da297c011c4b11543e","name":"karma","label":"karma","normalized_name":"unit_karma","type":"point","abbreviation":"kar","display_priority":0}' }

  before do
    stub_request(:get, "#{url}/#{key}/sites/bar.com.json").to_return(:status => 404, :body => '')
    stub_request(:post, "#{url}/#{key}/sites.json").to_return(:status => 200, :body => site_response)
    stub_request(:get, "#{url}/#{key}/units.json?page=1&per_page=50&site=bar.com").to_return(:status => 404, :body => '')
    stub_request(:post, "#{url}/#{key}/units.json").to_return(:status => 200, :body => unit_response)
    Gamifier.set :uri => url, :key => key, :enterprise_key => enterprise_key
  end

  context "when network already exists" do

    let(:network_error_response) { '{"name":["is already taken"],"label":["is already taken"]}' }

    before do
      stub_request(:post, "#{url}/#{enterprise_key}/networks.json").to_return(:status => 422, :body => network_error_response)
    end

    it { expect { network.save_network! }.to_not raise_error }

  end

  context "when network does not exists" do

    let(:api_key_response) { '{"id":"51122b073dc6480b760f66ce","network_id":"5112257849f8387b000e85f6","key":"5c3782a61ff639c92c30ea73d294e25e","access":"private","enable_whitelist":false,"ip_addresses":null}' }

    before do
      stub_request(:post, "#{url}/#{enterprise_key}/networks.json").to_return(:status => 200, :body => network_response)
      stub_request(:post, "#{url}/#{enterprise_key}/api_keys.json").to_return(:status => 200, :body => api_key_response)
    end

    it { expect { network.save_network! }.to_not raise_error }

  end

  it { expect{ network.save! }.to_not raise_error }

  it "should work twice" do
    expect{ network.save! }.to_not raise_error
    expect{ network.save! }.to_not raise_error
  end
end
