require 'spec_integration_helper'

describe "managing players" do

  before do
    destroy_test_player!
  end

  it "should list all players" do
    players = Gamifier.engine.players.all
    players.all?{|p| p.kind_of?(Gamifier::Player)}.should be_true
  end

  it "should create a new player" do
    find_or_create_test_user
    player = Gamifier.engine.players.build(player_attributes)
    player.save
    Gamifier.engine.players.find(player._id).should_not be_nil
  end

  describe "with an existing player" do

    before do
      @player = find_or_create_test_player
    end

    it "should credit an activity for the player" do
      activity = @player.credit("visit", :contents_attributes => [{:content_url => "http://dimelo.com", :content_type => "page", :title => "Test1"}])
      activity.should_not be_false
      activity.contents.first["title"].should == "Test1"
      activity.rewards.should be_empty
      activity.points.should == 1
    end

    it "should update the picture_url" do
      url = "http://s3.amazonaws.com/crohr.dimelo/identity_avatars/2ffbf54be4af49e7/avatar_normal.png?f59510d"
      @player.picture_url = url
      @player.save.should be_true
      Gamifier.engine.players.find(@player._id).picture_url.should == url
    end

  end

end
