require 'spec_helper'

describe Gamifier::DSL::Site do

  let(:site) { Gamifier::DSL::Site.new }
  let(:url) { 'http://foo.com' }
  let(:key) { '1234' }
  let(:enterprise_key) { '5678' }

  before do
    Gamifier.set :uri => url, :key => key, :enterprise_key => enterprise_key
  end

  describe "#initialize" do

    subject { site }

    its(:source) { should_not be_nil }
    its(:units) { should be_empty }
    its(:behaviors) { should be_empty }
    its(:rewards) { should be_empty }
    its(:missions) { should be_empty }
    its(:tracks) { should be_empty }

  end

  describe "#engine" do

    subject { site.engine }

    it { should eq(Gamifier.engine) }

  end

  describe "#method_missing" do

    let(:args) { 'bar' }
    let(:block) { lambda {|x| x} }

    it "should call on source" do
      site.source.should_receive(:foo).with(args, &block)
      site.foo(args, &block)
    end

  end

  describe "#unit" do

    it { expect { site.unit('foo') }.to change{ site.units.count }.by(1) }
    it { subject.unit('foo').name.should eq('foo') }

    it "should call eval_with_context" do
      block = proc {}
      Gamifier::DSL.should_receive(:eval_with_context).with(instance_of(Gamifier::Unit), &block)
      site.unit('foo', &block)
    end

    it "should set values" do
      o = site.unit('foo') do
        set :key, 'value'
      end
      o.key.should eq('value')
    end

  end

  describe "#behavior" do

    it { expect { site.behavior('foo') }.to change{ site.behaviors.count }.by(1) }
    it { subject.behavior('foo').name.should eq('foo') }

    it "should call eval_with_context" do
      block = proc {}
      Gamifier::DSL.should_receive(:eval_with_context).with(instance_of(Gamifier::ActivityDefinition), &block)
      site.behavior('foo', &block)
    end

    it "should set values" do
      o = site.behavior('foo') do
        set :key, 'value'
      end
      o.key.should eq('value')
    end

  end

  describe "#reward" do

    it { expect { site.reward('foo') }.to change{ site.rewards.count }.by(1) }
    it { subject.reward('foo').name.should eq('foo') }

    it "should call eval_with_context" do
      block = proc {}
      Gamifier::DSL.should_receive(:eval_with_context).with(instance_of(Gamifier::RewardDefinition), &block)
      site.reward('foo', &block)
    end

    it "should set values" do
      o = site.reward('foo') do
        set :key, 'value'
      end
      o.key.should eq('value')
    end

  end

  describe "#mission" do

    it { expect { site.mission('foo') }.to change{ site.missions.count }.by(1) }
    it { subject.mission('foo').name.should eq('foo') }

    it "should call eval_with_context" do
      block = proc {}
      Gamifier::DSL.should_receive(:eval_with_context).with(instance_of(Gamifier::Group), &block)
      site.mission('foo', &block)
    end

    it "should set values" do
      o = site.mission('foo') do
        set :key, 'value'
      end
      o.key.should eq('value')
    end

  end

  describe "#track" do

    it { expect { site.track('foo') }.to change{ site.tracks.count }.by(1) }
    it { subject.track('foo').label.should eq('foo') }

    it "should call eval_with_context" do
      block = proc {}
      Gamifier::DSL.should_receive(:eval_with_context).with(instance_of(Gamifier::Track), &block)
      site.track('foo', &block)
    end

    it "should set values" do
      o = site.track('foo') do
        set :key, 'value'
      end
      o.key.should eq('value')
    end

  end

end
