require 'spec_helper'

describe Gamifier do

  before do
    Gamifier.reset!
  end

  it "should allow to set the API URI" do
    Gamifier.set :uri, "http://somwhere.ltd"
    Gamifier.config[:uri].should eq "http://somwhere.ltd"
  end

  it "should allow to set the API KEY" do
    Gamifier.set :key, "1234"
    Gamifier.config[:key].should eq "1234"
  end

  it "should allow to set multiple configuration options at once" do
    Gamifier.set :uri => "http://somewhere.ltd", "key" => "1234"
    Gamifier.config[:uri].should eq "http://somewhere.ltd"
    Gamifier.config[:key].should eq "1234"
  end

  it "should allow to reset the state" do
    Gamifier.set :key, "http://somewhere.ltd"
    Gamifier.reset!
    Gamifier.config.should be_empty
  end

  it "should accept a logger object" do
    logger = mock("logger")
    Gamifier.logger = logger
    Gamifier.logger.should eq logger
  end

  describe "with proper configuration" do

    before do
      Gamifier.set :uri => "http://somewhere.ltd/path/", :key => "1234"
    end

    it "should return a singleton object when calling Gamifier#engine" do
      engine = Gamifier.engine
      engine.should be_a(Object)
      Gamifier.engine.should be_equal(engine)
    end

    it "should return an instance of Gamifier::Engine" do
      Gamifier.engine.should be_instance_of(Gamifier::Engine)
    end

    it "should create a new engine object after reset" do
      engine = Gamifier.engine
      Gamifier.reset!
      Gamifier.set :uri => "http://somewhere.ltd/path/", :key => "1234"
      Gamifier.engine.should_not be_equal(engine)
    end

  end

end
