require 'spec_helper'

describe Gamifier::Player do

  let(:engine) { mock(Gamifier::Engine) }

  describe "crediting" do

    it "should create a new activity and save it" do
      player = Gamifier::Player.new(:_id => "1234")
      player.engine = engine

      engine.should_receive(:activities).
        and_return(collection = mock(Gamifier::Collection))
      collection.should_receive(:build).
        with(:data1 => "value", :player_id => "1234", :verb => "event").
        and_return(mock(Gamifier::Activity, :save => true))

      player.credit('event', :data1 => "value").should == true
    end

  end

  describe "FinderMethods" do

    before do
      @collection = Gamifier::Collection.new(engine, Gamifier::Player)
    end

    it "should have included all the methods" do
      (Gamifier::Model::FinderMethods.public_instance_methods + Gamifier::Player::FinderMethods.public_instance_methods).uniq.each do |method|
        @collection.should respond_to(method)
      end
    end

    describe "find_by_site_and_email" do

      it "should issue a get request with the correct params" do
        engine.should_receive(:transmit).with(:get, "players", :query => {:site=>"test.ltd", :email=>"hi@hello.com", :limit => 5})
        @collection.find_by_site_and_email 'test.ltd', 'hi@hello.com', :limit => 5
      end

    end

    describe "find_by_player_id" do

      let(:player_id) { '123456789' }

      it "should issue a get request with the correct params" do
        engine.should_receive(:transmit).with(:get, "players/#{player_id}")
        @collection.find_by_player_id(player_id)
      end

    end

  end

end
